@@ -29,6 +29,7 @@
 
 #include <list>
 #include <map>
+#include <set>
 #include <string>
 #include <libxml/tree.h>
 #include <gtk/gtk.h>
@@ -97,7 +98,7 @@ public:
 	void ParseXMLTree(xmlDocPtr xml);
 	void LoadObjects(xmlNodePtr node);
 	xmlDocPtr BuildXMLTree();
-	void NotifyDirty(gcpBond* pBond){m_DirtyObjects.push_back(pBond);}
+	void NotifyDirty (gcpBond* pBond) {m_DirtyObjects.insert (pBond);}
 	void Update();
 	void Remove(Object*);
 	void Remove(const char* Id);
@@ -145,7 +146,7 @@ private:
 	gchar *m_title;
 	gchar *m_label;
 	gchar *m_comment, *m_author, *m_mail;
-	list<Object*>m_DirtyObjects;
+	set<Object*>m_DirtyObjects;
 	BonoboPersist* m_ps;
 	bool m_bDirty, m_bIsLoading, m_bUndoRedo, m_bReadOnly;
 	int m_FileType;
